==> nomachine-7.10.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXProfilesDB.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXProfilesDB;no warnings;require NXPaths;sub BEGIN{require Error;do{
"\x45\x72\x72\x6f\x72"->import ("\x3a\x74\x72\x79")};}sub BEGIN{require 
Exception::Log;do{"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x4c\x6f\x67"->
import};}(my $__databaseInitialized=(0x186f+ 208-0x193f));(my $__userSidsInitialized
=(0x04a0+ 5298-0x1952));(my (%__profiles)=());(my (%__loadedProfiles)=());(my $__fields_in_record
=(0x0c7a+ 1003-0x104b));sub save{Logger::debug (
"\x4e\x58\x50\x72\x6f\x66\x69\x6c\x65\x73\x44\x42\x3a\x20\x53\x61\x76\x69\x6e\x67\x20\x70\x72\x6f\x66\x69\x6c\x65\x73\x2e"
);if ((not (%__profiles))){NXRedis::sendToDbAndSave (
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x64\x65\x6c\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x70\x72\x6f\x66\x69\x6c\x65\x73\x0a"
);}else{my ($command);foreach my $key (keys (%__profiles)){(my $line=join (
"\x3a",@{$__profiles{$key};}));(my $record=main::urlencode ($line));($key=
main::urlencode ($key));if (($record ne $__loadedProfiles{$key})){($command.=(((
"\x2c\x66\x69\x65\x6c\x64\x3d".$key)."\x2c\x76\x61\x6c\x75\x65\x3d").$record));}
delete ($__loadedProfiles{$key});(my $length=length ($command));if (($length>
15000)){NXRedis::sendToDbAndSave (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x6d\x73\x65\x74\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x70\x72\x6f\x66\x69\x6c\x65\x73"
.$command)."\x0a"));($command=(""));}}if (($command ne (""))){
NXRedis::sendToDbAndSave (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x6d\x73\x65\x74\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x70\x72\x6f\x66\x69\x6c\x65\x73"
.$command)."\x0a"));}if (%__loadedProfiles){my ($commandDel);foreach my $key (
keys (%__loadedProfiles)){($commandDel.=("\x2c\x66\x69\x65\x6c\x64\x3d".$key));}
if (($commandDel ne (""))){NXRedis::sendToDbAndSave (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x64\x65\x6c\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x70\x72\x6f\x66\x69\x6c\x65\x73"
.$commandDel)."\x0a"));}}resetDB ();}return ((0x09d6+ 4995-0x1d59));}sub __load{
NXRedis::sendToDb (
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x67\x65\x74\x61\x6c\x6c\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x70\x72\x6f\x66\x69\x6c\x65\x73\x0a"
);((%__loadedProfiles)=split ( / / ,NXRedis::get (),(0x0689+ 6283-0x1f14)));
foreach my $key (keys (%__loadedProfiles)){(my $record=main::urldecode (
$__loadedProfiles{$key}));($key=main::urldecode ($key));(my (@recordArray)=split
 ( /:/ ,$record,(0x2267+ 460-0x2433)));($__profiles{$key}=(\@recordArray));}
__convertUsernamesInKeysToAbsoluteUsername ();($__databaseInitialized=
(0x119b+ 1768-0x1882));}sub getDatabaseInString{__load ();(my $string=
NXShell::hashParameters2Url (%__loadedProfiles));return ($string);}sub 
setDatabaseByString{(my $string=shift (@_));if (($string eq (""))){return (
(0x0e49+ 3183-0x1ab8));}(my (%tmpProfiles)=NXShell::urlParameter2Hash ($string))
;foreach my $key (keys (%tmpProfiles)){(my (@recordArray)=split ( /:/ ,
main::urldecode ($tmpProfiles{$key}),(0x0f33+ 5531-0x24ce)));($__profiles{$key}=
(\@recordArray));}save ();return ((0x0060+ 6099-0x1833));}sub 
getProfileServerSetInString{NXRedis::sendToDb (
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x6d\x65\x6d\x62\x65\x72\x73\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x70\x72\x6f\x66\x69\x6c\x65\x73\x2e\x73\x65\x72\x76\x65\x72\x73\x54\x6f\x43\x68\x65\x63\x6b\x0a"
);return (main::urlencode (NXRedis::get ()));}sub getProfileGroupSetInString{
NXRedis::sendToDb (
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x6d\x65\x6d\x62\x65\x72\x73\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x70\x72\x6f\x66\x69\x6c\x65\x73\x2e\x67\x72\x6f\x75\x70\x73\x54\x6f\x43\x68\x65\x63\x6b\x0a"
);return (main::urlencode (NXRedis::get ()));}sub saveProfileServerSetByString{(my $string
=shift (@_));(my (@servers)=split ( / / ,main::urldecode ($string),
(0x0804+ 1362-0x0d56)));if ((scalar (@servers)==(0x1c14+ 2250-0x24de))){
Logger::debug (
"\x4e\x6f\x20\x73\x65\x72\x76\x65\x72\x73\x20\x74\x6f\x20\x73\x61\x76\x65\x20\x69\x6e\x20\x70\x72\x6f\x66\x69\x6c\x65\x20\x73\x65\x74\x2e\x20\x53\x6b\x69\x70\x70\x69\x6e\x67\x2e"
);return ((0x197d+ 1564-0x1f99));}(my $command=
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x61\x64\x64\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x70\x72\x6f\x66\x69\x6c\x65\x73\x2e\x73\x65\x72\x76\x65\x72\x73\x54\x6f\x43\x68\x65\x63\x6b"
);foreach my $serverToAdd (@servers){($command.=("\x2c\x66\x69\x65\x6c\x64\x3d".
$serverToAdd));}($command.="\x0a");NXRedis::sendToDbAndSave ($command);return (
(0x06e8+ 7957-0x25fd));}sub saveProfileGroupSetByString{(my $string=shift (@_));
(my (@groups)=split ( / / ,main::urldecode ($string),(0x1dd3+ 198-0x1e99)));if (
(scalar (@groups)==(0x071d+ 5501-0x1c9a))){Logger::debug (
"\x4e\x6f\x20\x67\x72\x6f\x75\x70\x73\x20\x74\x6f\x20\x73\x61\x76\x65\x20\x69\x6e\x20\x70\x72\x6f\x66\x69\x6c\x65\x20\x73\x65\x74\x2e\x20\x53\x6b\x69\x70\x70\x69\x6e\x67\x2e"
);return ((0x0fa5+ 3538-0x1d77));}(my $command=
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x61\x64\x64\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x70\x72\x6f\x66\x69\x6c\x65\x73\x2e\x67\x72\x6f\x75\x70\x73\x54\x6f\x43\x68\x65\x63\x6b"
);foreach my $groupToAdd (@groups){($command.=("\x2c\x66\x69\x65\x6c\x64\x3d".
$groupToAdd));}($command.="\x0a");NXRedis::sendToDbAndSave ($command);return (
(0x1318+ 5093-0x26fd));}sub cleanDb{NXRedis::sendToDb (
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x64\x65\x6c\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x70\x72\x6f\x66\x69\x6c\x65\x73\x0a"
);resetDB ();((%__loadedProfiles)=());}sub getDatabaseReference{if ((
$__databaseInitialized==(0x02ac+ 8555-0x2417))){__load ();}return ((\%__profiles
));}sub getEmptyProfile{return ((((""))x $__fields_in_record));}sub resetDB{
Logger::debug (
"\x4e\x58\x50\x72\x6f\x66\x69\x6c\x65\x73\x44\x42\x3a\x20\x52\x65\x73\x65\x74\x69\x6e\x67\x20\x70\x72\x6f\x66\x69\x6c\x65\x73\x2e"
);($__databaseInitialized=(0x131a+ 4831-0x25f9));foreach my $key (keys (
%__profiles)){delete ($__profiles{$key});}}sub 
__convertUsernamesInKeysToAbsoluteUsername{if ((($__userSidsInitialized==
(0x0293+ 2987-0x0e3d))or ($GLOBAL::DisableUsernameConversion==
(0x0660+ 2098-0x0e91)))){return;}Logger::debug (
"\x4e\x58\x50\x72\x6f\x66\x69\x6c\x65\x73\x44\x42\x3a\x20\x43\x6f\x6e\x76\x65\x72\x74\x69\x6e\x67\x20\x75\x73\x65\x72\x6e\x61\x6d\x65\x73\x20\x74\x6f\x20\x53\x49\x44\x73\x2e"
);foreach my $key (keys (%__profiles)){(my $convertedKey=$key);
convertUsernameInKeyToAbsoluteUsername ((\$convertedKey));if (($convertedKey ne 
$key)){($__profiles{$convertedKey}=$__profiles{$key});delete ($__profiles{$key})
;}}($__userSidsInitialized=(0x0d14+ 3457-0x1a94));}sub 
convertUsernameInKeyToAbsoluteUsername{if (($GLOBAL::DisableUsernameConversion==
(0x0953+ 5587-0x1f25))){return;}(my $ref_key=shift (@_));if ((
__convertUsernameInNodeAndUserProfileKeyToAbsoluteUsername ($ref_key)==
(0x2247+ 958-0x2604))){return;}if ((
__convertUsernameInUserProfileKeyToAbsoluteUsername ($ref_key)==
(0x0d6f+ 3082-0x1978))){return;}}sub 
__convertUsernameInNodeAndUserProfileKeyToAbsoluteUsername{(my $ref_key=shift (
@_));if (($$ref_key=~ /(.*),(.*)/ )){(my $node=$1);(my $user=$2);if (($node=~ /\// )
){if ((__convertUsernameInUserProfileKeyToAbsoluteUsername ((\$user))==
(0x00ea+ 780-0x03f5))){($$ref_key=(($node."\x2c").$user));}}return (
(0x17d9+ 1320-0x1d00));}return ((0x0e62+ 4648-0x208a));}sub 
__convertUsernameInUserProfileKeyToAbsoluteUsername{(my $ref_key=shift (@_));if 
(NXProfiles::isInternalKey ($$ref_key)){return ((0x1470+ 2163-0x1ce3));}if ((
$$ref_key eq (""))){Logger::debug (
"\x4e\x58\x50\x72\x6f\x66\x69\x6c\x65\x73\x44\x42\x3a\x20\x54\x72\x79\x69\x6e\x67\x20\x74\x6f\x20\x63\x68\x65\x63\x6b\x20\x65\x6d\x70\x74\x79\x20\x6b\x65\x79\x2e"
);return ((0x1923+ 2294-0x2219));}if (($$ref_key=~ /__group__/ )){return (
(0x0625+ 2287-0x0f14));}if (($$ref_key=~ /\// )){return ((0x1006+ 1523-0x15f9));
}if (($$ref_key=~ /__nodegroup__/ )){return ((0x0736+ 6039-0x1ecd));}if ((
$$ref_key=~ /__servergroup__/ )){return ((0x05a6+ 3932-0x1502));}if (($$ref_key
=~ /__address__/ )){return ((0x1974+ 804-0x1c98));}(my $username=
NXLogin::getAbsoluteNameForUsername ($$ref_key));($$ref_key=$username);return (
(0x1ba7+ 2415-0x2515));}sub reloadProfilesDB{($__databaseInitialized=
(0x056d+ 5240-0x19e5));($__userSidsInitialized=(0x10e8+ 4271-0x2197));((
%__profiles)=());__load ();if (NXProfiles::isPropagatedRuleToOverwrite ()){
NXProfiles::overwritePropagatedRules ();}}"\x3f\x3f\x3f";

==> nomachine-8.0.168-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXProfilesDB.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXProfilesDB;no warnings;require NXPaths;sub BEGIN{require Error;do{
"\x45\x72\x72\x6f\x72"->import ("\x3a\x74\x72\x79")};}sub BEGIN{require 
Exception::Log;do{"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x4c\x6f\x67"->
import};}(my $__databaseInitialized=(0x1997+ 2846-0x24b5));(my $__userSidsInitialized
=(0x07b6+ 4241-0x1847));(my (%__profiles)=());(my (%__loadedProfiles)=());(my $__fields_in_record
=(0x0268+ 3333-0x0f53));sub save{Logger::debug (
"\x4e\x58\x50\x72\x6f\x66\x69\x6c\x65\x73\x44\x42\x3a\x20\x53\x61\x76\x69\x6e\x67\x20\x70\x72\x6f\x66\x69\x6c\x65\x73\x2e"
);if ((not (%__profiles))){NXRedis::sendToDbAndSave (
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x64\x65\x6c\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x70\x72\x6f\x66\x69\x6c\x65\x73\x0a"
);}else{my ($command);foreach my $key (keys (%__profiles)){(my $line=join (
"\x3a",@{$__profiles{$key};}));(my $record=main::urlencode ($line));($key=
main::urlencode ($key));if (($record ne $__loadedProfiles{$key})){($command.=(((
"\x2c\x66\x69\x65\x6c\x64\x3d".$key)."\x2c\x76\x61\x6c\x75\x65\x3d").$record));}
delete ($__loadedProfiles{$key});(my $length=length ($command));if (($length>
15000)){NXRedis::sendToDbAndSave (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x6d\x73\x65\x74\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x70\x72\x6f\x66\x69\x6c\x65\x73"
.$command)."\x0a"));($command=(""));}}if (($command ne (""))){
NXRedis::sendToDbAndSave (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x6d\x73\x65\x74\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x70\x72\x6f\x66\x69\x6c\x65\x73"
.$command)."\x0a"));}if (%__loadedProfiles){my ($commandDel);foreach my $key (
keys (%__loadedProfiles)){($commandDel.=("\x2c\x66\x69\x65\x6c\x64\x3d".$key));}
if (($commandDel ne (""))){NXRedis::sendToDbAndSave (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x64\x65\x6c\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x70\x72\x6f\x66\x69\x6c\x65\x73"
.$commandDel)."\x0a"));}}resetDB ();}return ((0x0cc8+ 2385-0x1619));}sub __load{
NXRedis::sendToDb (
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x67\x65\x74\x61\x6c\x6c\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x70\x72\x6f\x66\x69\x6c\x65\x73\x0a"
);((%__loadedProfiles)=split ( / / ,NXRedis::get (),(0x1380+ 4558-0x254e)));
foreach my $key (keys (%__loadedProfiles)){(my $record=main::urldecode (
$__loadedProfiles{$key}));($key=main::urldecode ($key));(my (@recordArray)=split
 ( /:/ ,$record,(0x0742+ 4158-0x1780)));($__profiles{$key}=(\@recordArray));}
__convertUsernamesInKeysToAbsoluteUsername ();($__databaseInitialized=
(0x1106+ 1655-0x177c));}sub getDatabaseInString{__load ();(my $string=
NXShell::hashParameters2Url (%__loadedProfiles));return ($string);}sub 
setDatabaseByString{(my $string=shift (@_));if (($string eq (""))){return (
(0x1054+ 1054-0x1472));}(my (%tmpProfiles)=NXShell::urlParameter2Hash ($string))
;foreach my $key (keys (%tmpProfiles)){(my (@recordArray)=split ( /:/ ,
main::urldecode ($tmpProfiles{$key}),(0x02ea+ 5958-0x1a30)));($__profiles{$key}=
(\@recordArray));}save ();return ((0x1e73+ 1819-0x258e));}sub 
getProfileServerSetInString{NXRedis::sendToDb (
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x6d\x65\x6d\x62\x65\x72\x73\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x70\x72\x6f\x66\x69\x6c\x65\x73\x2e\x73\x65\x72\x76\x65\x72\x73\x54\x6f\x43\x68\x65\x63\x6b\x0a"
);return (main::urlencode (NXRedis::get ()));}sub getProfileGroupSetInString{
NXRedis::sendToDb (
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x6d\x65\x6d\x62\x65\x72\x73\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x70\x72\x6f\x66\x69\x6c\x65\x73\x2e\x67\x72\x6f\x75\x70\x73\x54\x6f\x43\x68\x65\x63\x6b\x0a"
);return (main::urlencode (NXRedis::get ()));}sub saveProfileServerSetByString{(my $string
=shift (@_));(my (@servers)=split ( / / ,main::urldecode ($string),
(0x00af+ 4362-0x11b9)));if ((scalar (@servers)==(0x04c5+ 329-0x060e))){
Logger::debug (
"\x4e\x6f\x20\x73\x65\x72\x76\x65\x72\x73\x20\x74\x6f\x20\x73\x61\x76\x65\x20\x69\x6e\x20\x70\x72\x6f\x66\x69\x6c\x65\x20\x73\x65\x74\x2e\x20\x53\x6b\x69\x70\x70\x69\x6e\x67\x2e"
);return ((0x04d8+ 7676-0x22d4));}(my $command=
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x61\x64\x64\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x70\x72\x6f\x66\x69\x6c\x65\x73\x2e\x73\x65\x72\x76\x65\x72\x73\x54\x6f\x43\x68\x65\x63\x6b"
);foreach my $serverToAdd (@servers){($command.=("\x2c\x66\x69\x65\x6c\x64\x3d".
$serverToAdd));}($command.="\x0a");NXRedis::sendToDbAndSave ($command);return (
(0x0544+ 5551-0x1af3));}sub saveProfileGroupSetByString{(my $string=shift (@_));
(my (@groups)=split ( / / ,main::urldecode ($string),(0x177f+ 2205-0x201c)));if 
((scalar (@groups)==(0x04d5+ 6488-0x1e2d))){Logger::debug (
"\x4e\x6f\x20\x67\x72\x6f\x75\x70\x73\x20\x74\x6f\x20\x73\x61\x76\x65\x20\x69\x6e\x20\x70\x72\x6f\x66\x69\x6c\x65\x20\x73\x65\x74\x2e\x20\x53\x6b\x69\x70\x70\x69\x6e\x67\x2e"
);return ((0x161f+ 4161-0x2660));}(my $command=
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x61\x64\x64\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x70\x72\x6f\x66\x69\x6c\x65\x73\x2e\x67\x72\x6f\x75\x70\x73\x54\x6f\x43\x68\x65\x63\x6b"
);foreach my $groupToAdd (@groups){($command.=("\x2c\x66\x69\x65\x6c\x64\x3d".
$groupToAdd));}($command.="\x0a");NXRedis::sendToDbAndSave ($command);return (
(0x25c1+ 295-0x26e8));}sub cleanDb{NXRedis::sendToDb (
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x64\x65\x6c\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x70\x72\x6f\x66\x69\x6c\x65\x73\x0a"
);resetDB ();((%__loadedProfiles)=());}sub getDatabaseReference{if ((
$__databaseInitialized==(0x02a9+ 6777-0x1d22))){__load ();}return ((\%__profiles
));}sub getEmptyProfile{return ((((""))x $__fields_in_record));}sub resetDB{
Logger::debug (
"\x4e\x58\x50\x72\x6f\x66\x69\x6c\x65\x73\x44\x42\x3a\x20\x52\x65\x73\x65\x74\x69\x6e\x67\x20\x70\x72\x6f\x66\x69\x6c\x65\x73\x2e"
);($__databaseInitialized=(0x06b2+ 1497-0x0c8b));foreach my $key (keys (
%__profiles)){delete ($__profiles{$key});}}sub 
__convertUsernamesInKeysToAbsoluteUsername{if ((($__userSidsInitialized==
(0x0c22+ 2165-0x1496))or ($GLOBAL::DisableUsernameConversion==
(0x0641+ 2596-0x1064)))){return;}Logger::debug (
"\x4e\x58\x50\x72\x6f\x66\x69\x6c\x65\x73\x44\x42\x3a\x20\x43\x6f\x6e\x76\x65\x72\x74\x69\x6e\x67\x20\x75\x73\x65\x72\x6e\x61\x6d\x65\x73\x20\x74\x6f\x20\x53\x49\x44\x73\x2e"
);foreach my $key (keys (%__profiles)){(my $convertedKey=$key);
convertUsernameInKeyToAbsoluteUsername ((\$convertedKey));if (($convertedKey ne 
$key)){($__profiles{$convertedKey}=$__profiles{$key});delete ($__profiles{$key})
;}}($__userSidsInitialized=(0x18f7+ 1439-0x1e95));}sub 
convertUsernameInKeyToAbsoluteUsername{if (($GLOBAL::DisableUsernameConversion==
(0x0981+ 4469-0x1af5))){return;}(my $ref_key=shift (@_));if ((
__convertUsernameInNodeAndUserProfileKeyToAbsoluteUsername ($ref_key)==
(0x02d0+ 1094-0x0715))){return;}if ((
__convertUsernameInUserProfileKeyToAbsoluteUsername ($ref_key)==
(0x097f+ 6695-0x23a5))){return;}}sub 
__convertUsernameInNodeAndUserProfileKeyToAbsoluteUsername{(my $ref_key=shift (
@_));if (($$ref_key=~ /(.*),(.*)/ )){(my $node=$1);(my $user=$2);if (($node=~ /\// )
){if ((__convertUsernameInUserProfileKeyToAbsoluteUsername ((\$user))==
(0x04f4+ 7666-0x22e5))){($$ref_key=(($node."\x2c").$user));}}return (
(0x09e3+ 6142-0x21e0));}return ((0x1a17+ 531-0x1c2a));}sub 
__convertUsernameInUserProfileKeyToAbsoluteUsername{(my $ref_key=shift (@_));if 
(NXProfiles::isInternalKey ($$ref_key)){return ((0x0c68+ 1844-0x139c));}if ((
$$ref_key eq (""))){Logger::debug (
"\x4e\x58\x50\x72\x6f\x66\x69\x6c\x65\x73\x3a\x20\x74\x72\x79\x69\x6e\x67\x20\x74\x6f\x20\x63\x68\x65\x63\x6b\x20\x65\x6d\x70\x74\x79\x20\x6b\x65\x79\x2e"
);return ((0x0c53+ 4336-0x1d43));}if (NXNodes::isUUID ($$ref_key)){return (
(0x1bfc+ 1618-0x224e));}if (($$ref_key=~ /__group__/ )){return (
(0x07db+ 2388-0x112f));}if (($$ref_key=~ /\// )){return ((0x0839+ 4787-0x1aec));
}if (($$ref_key=~ /__nodegroup__/ )){return ((0x0078+ 5367-0x156f));}if ((
$$ref_key=~ /__servergroup__/ )){return ((0x16b6+ 2967-0x224d));}if (($$ref_key
=~ /__address__/ )){return ((0x0094+ 5206-0x14ea));}(my $username=
NXLogin::getAbsoluteNameForUsername ($$ref_key));($$ref_key=$username);return (
(0x1175+ 1749-0x1849));}sub reloadProfilesDB{($__databaseInitialized=
(0x0e3c+ 3661-0x1c89));($__userSidsInitialized=(0x0971+ 498-0x0b63));((
%__profiles)=());__load ();if (NXProfiles::isPropagatedRuleToOverwrite ()){
NXProfiles::overwritePropagatedRules ();}}"\x3f\x3f\x3f";
